<?php

namespace Drupal\commerce_billbee\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 */
class SettingsForm extends ConfigFormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'commerce_billbee_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'commerce_billbee.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('commerce_billbee.settings');

    $form['api_key'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Billbee API key'),
      '#default_value' => $config->get('api_key'),
      '#required' => TRUE,
      '#description' => $this->t('Fill in a random key here. When you create a shop connection in Bilbee, enter the same key in the shop connection settings on Bilbee as entered here.'),

    );

    $all_image_fields = \Drupal::service('entity_field.manager')->getFieldMapByFieldType('image');
    $available_image_fields = ['_none' => t('No image mapping')];
    if(isset($all_image_fields['commerce_product_variation'])){
      foreach($all_image_fields['commerce_product_variation'] as $field_id => $data){
        $available_image_fields[$field_id] = $field_id;
      }
    }
    $form['image_field'] = [
      '#title' => $this->t('Image field mapping'),
      '#type' => 'select',
      '#options' => $available_image_fields,
      '#default_value' => $config->get('image_field'),
      '#description' => $this->t('All image fields defined on a product variation are available here. If you do not want to syncronise images, set to "No image mapping".'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('commerce_billbee.settings')
      ->set('api_key', $values['api_key'])
      ->set('image_field', $values['image_field'])
      ->save();
    parent::submitForm($form, $form_state);
  }

}
